package prometheus-lwt

  1. Overview
  2. Docs

Module Prometheus_lwt.CollectorRegistrySource

Sourcetype t

of_registry core is the Lwt view over the existing registry core.

Sourceval default : t

default is the view over Prometheus.CollectorRegistry.default.

core t is the underlying core registry. Use it to register synchronous metrics.

collect t reads the current value of every metric.

register t info collector registers a collector that may suspend before producing its samples.

Sourceval register_pre_collect : t -> (unit -> unit Lwt.t) -> unit

register_pre_collect t f arranges for f () to run at the start of each collection.